@@ -22,6 +22,10 @@ projects:
     documents: graphql/**.graphql
     extensions:
       turms:
+        out_dir: examples/api
+        stylers:
+          - type: turms.styler.capitalize.Capitalizer
+          - type: turms.styler.appender.Appender
         plugins:
           - type: turms.plugins.enums.EnumsPlugin
           - type: turms.plugins.inputs.InputsPlugin
