@@ -3,6 +3,7 @@ import ast
 from typing import List
 from turms.config import GeneratorConfig
 from graphql.utilities.build_client_schema import GraphQLSchema
+from turms.registry import ClassRegistry
 
 
 class Plugin:
@@ -12,13 +13,11 @@ class Plugin:
         NotImplementedError: [description]
     """
 
-    def generate_imports(
-        self, config: GeneratorConfig, client_schema: GraphQLSchema
-    ) -> List[ast.AST]:
-        return []
-
     @abstractmethod
-    def generate_body(
-        self, config: GeneratorConfig, client_schema: GraphQLSchema
+    def generate_tree(
+        self,
+        config: GeneratorConfig,
+        client_schema: GraphQLSchema,
+        registry: ClassRegistry,
     ) -> List[ast.AST]:
         raise NotImplementedError("Plugin must overrwrite this")
